==> muffin-0.5.zip: muffin-0.5/src/muffin/Client.java <==
/* Client.java */

/* 
 * Copyright (C) 1996-97 Mark Boyns <boyns@sdsu.edu>
 *
 * This file is part of Muffin.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package muffin;

import java.io.IOException;
import java.net.Socket;

/**
 * Client which reads a Request and writes a Reply.
 *
 * @see muffin.Request
 * @see muffin.Reply
 * @author Mark Boyns
 */
public class Client extends Connection
{
    /**
     * Create a Client from a Socket.
     */
    public Client (Socket s) throws IOException
    {
	super (s);
    }

    /**
     * Read a Request.
     *
     * @returns a Request.
     * @see muffin.Request
     */
    public Request read () throws IOException
    {
	Request request = new Request ();
	request.read (in);
	return request;
    }

    /**
     * Write a Reply
     *
     * @see muffin.Reply
     */
    public void write (Reply reply) throws IOException
    {
	reply.write (out);
    }
}

==> muffin-0.6.zip: muffin-0.6/src/muffin/Client.java <==
/* Client.java */

/* 
 * Copyright (C) 1996-98 Mark Boyns <boyns@sdsu.edu>
 *
 * This file is part of Muffin.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package muffin;

import java.io.IOException;
import java.net.Socket;

/**
 * Client which reads a Request and writes a Reply.
 *
 * @see muffin.Request
 * @see muffin.Reply
 * @author Mark Boyns
 */
class Client extends Connection
{
    /**
     * Create a Client from a Socket.
     */
    Client (Socket s) throws IOException
    {
	super (s);
    }

    /**
     * Read a Request.
     *
     * @returns a Request.
     * @see muffin.Request
     */
    Request read () throws IOException
    {
	Request request = new Request (this);
	request.read (in);
	return request;
    }

    /**
     * Write a Reply
     *
     * @see muffin.Reply
     */
    void write (Reply reply) throws IOException
    {
	reply.write (out);
    }
}
